"use strict";
/**
 * Used to create a virtual file using webpack compiler file system.
 * Extracted from the `mock-fs` package.
 *
 * @author SysGears INC. https://sysgears.com/
 * @link https://github.com/sysgears/webpack-virtual-modules/blob/master/index.js
 * @link https://github.com/sysgears/webpack-virtual-modules/blob/master/LICENSE
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const virtualStats_1 = require("./virtualStats");
let inode = 45000000;
function getData(storage, key) {
    if (storage.data instanceof Map) {
        return storage.data.get(key);
    }
    else {
        return storage.data[key];
    }
}
function setData(storage, key, value) {
    if (storage.data instanceof Map) {
        storage.data.set(key, value);
    }
    else {
        storage.data[key] = value;
    }
}
function writeVirtualFile(fs, file, stats, content) {
    setData(fs._statStorage, file, [null, stats]);
    setData(fs._readFileStorage, file, [null, content]);
    const segments = file.split(/[\\/]/);
    let count = segments.length - 1;
    const minCount = segments[0] ? 1 : 0;
    while (count > minCount) {
        const dir = segments.slice(0, count).join(path_1.default.sep) || path_1.default.sep;
        try {
            fs.readdirSync(dir);
        }
        catch (e) {
            const time = Date.now();
            /* tslint:disable:object-literal-sort-keys */
            const dirStats = new virtualStats_1.VirtualStats({
                dev: 8675309,
                nlink: 0,
                uid: 1000,
                gid: 1000,
                rdev: 0,
                blksize: 4096,
                ino: inode++,
                mode: 16877,
                size: stats.size,
                blocks: Math.floor(stats.size / 4096),
                atime: time,
                mtime: time,
                ctime: time,
                birthtime: time
            });
            /* tslint:enable:object-literal-sort-keys */
            setData(fs._readdirStorage, dir, [null, []]);
            setData(fs._statStorage, dir, [null, dirStats]);
        }
        const dirData = getData(fs._readdirStorage, dir);
        const filename = segments[count];
        if (dirData[1].indexOf(filename) < 0) {
            const files = dirData[1].concat([filename]).sort();
            setData(fs._readdirStorage, dir, [null, files]);
        }
        else {
            break;
        }
        count--;
    }
}
exports.writeVirtualFile = writeVirtualFile;
