"use strict";
/**
 * Used to cache a stats object for the virtual file.
 * Extracted from the `mock-fs` package.
 *
 * @author Tim Schaub http://tschaub.net/
 * @link https://github.com/tschaub/mock-fs/blob/master/lib/binding.js
 * @link https://github.com/tschaub/mock-fs/blob/master/license.md
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
/**
 * Create a new stats object.
 */
class VirtualStats {
    constructor(config) {
        for (const key in config) {
            if (!config.hasOwnProperty(key)) {
                continue;
            }
            this[key] = config[key];
        }
    }
    /**
     * Check if is a directory.
     */
    isDirectory() {
        return this._checkModeProperty(fs_1.default.constants.S_IFDIR);
    }
    /**
     * Check if is a regular file.
     */
    isFile() {
        return this._checkModeProperty(fs_1.default.constants.S_IFREG);
    }
    /**
     * Check if is a block device.
     */
    isBlockDevice() {
        return this._checkModeProperty(fs_1.default.constants.S_IFBLK);
    }
    /**
     * Check if is a character device.
     */
    isCharacterDevice() {
        return this._checkModeProperty(fs_1.default.constants.S_IFCHR);
    }
    /**
     * Check if is a symbolic link.
     */
    isSymbolicLink() {
        return this._checkModeProperty(fs_1.default.constants.S_IFLNK);
    }
    /**
     * Check if is a named pipe.
     */
    isFIFO() {
        return this._checkModeProperty(fs_1.default.constants.S_IFIFO);
    }
    /**
     * Check if is a socket.
     */
    isSocket() {
        return this._checkModeProperty(fs_1.default.constants.S_IFSOCK);
    }
    /**
     * Check if mode indicates property.
     */
    _checkModeProperty(property) {
        // tslint:disable-next-line:no-bitwise
        return (this.mode & fs_1.default.constants.S_IFMT) === property;
    }
}
exports.VirtualStats = VirtualStats;
